@@ -1,5 +1,7 @@
 import json 
 import boto3
+from io import BytesIO
+import pandas as pd
 
 config_file_path = "credentials.json" 
 
@@ -11,11 +13,12 @@ def _config():
 
 def load_data(file_name):
     config = _config()
-    return _get_object(config, config['bucket_name'], file_name)['Body'].read()
+    return BytesIO(_get_object(config, config['bucket_name'], file_name)['Body'].read())
 
-# Valid Formats: csv, json
-def save_data(file_name, data, format):
+def save_data(file_name, data):
     config = _config()
+    if isinstance(data, pd.DataFrame):
+        data = data.to_csv(index=False).encode()
     _put_object(config, config['bucket_name'], data, file_name)
 
 
